import requests
from bs4 import BeautifulSoup, Tag
import re
import json
import os

# gets the list of current versions from the dota patches site
def get_current_versions():
	response = requests.get("https://www.dota2.com/patches/7.29b")
	print(response.text)
	soup = BeautifulSoup(response.text, "html.parser")

	dropdown = soup.find_all("select", {"class": re.compile("patchnotespage_Selector_.*")})[0]

	for child in dropdown.contents:
		if child.name == "option" and "Select" not in child.contents[0]:
			print(child.contents[0])


def get_patch_dates():
	# copied these patch names from https://dota2.gamepedia.com/Game_Versions
	with open("old_patches.txt", "r") as f:
		patches = f.read().split("\n")

	patch_dates = {}
	for patch in patches:
		response = requests.get(f"https://dota2.gamepedia.com/Version_{patch}")
		soup = BeautifulSoup(response.text, "html.parser")
		for elem in soup(text=re.compile(r'^Release Date$')):
			date = str(elem.parent.nextSibling.contents[1].text)
			match = re.match(r"(\d{4}-\d{2}-\d{2})", date)
			if match:
				patch_dates[patch] = match.group()
			if not match:
				patch_dates[patch] = None
				print(patch, date)

	with open("patch_dates.json", "w+") as f:
		f.write(json.dumps(patch_dates, indent="\t"))

def cache_patches():
	# copied these patch names from https://dota2.gamepedia.com/Game_Versions
	with open("old_patches.txt", "r") as f:
		patches = f.read().split("\n")

	patch_dates = {}
	for patch in patches:
		outfile = f"cache/patch_{patch}.txt"
		if os.path.exists(outfile):
			continue # we already downloaded this one

		response = requests.get(f"https://dota2.gamepedia.com/Version_{patch}?action=edit")
		soup = BeautifulSoup(response.text, "html.parser")
		textarea = soup.find(id="wpTextbox1")
		if len(textarea.contents) > 0:
			text = textarea.contents[0].encode('utf-8')
		else:
			text = "".encode('utf-8')

		with open(outfile, "wb+") as f:
			f.write(text)


def fix_opendota_patches():
	opendota_path = "C:\\dev\\projects\\dotaconstants\\json\\patch.json"
	patch_dates_path = "patch_dates.json"

	with open(patch_dates_path, "r") as f:
		patch_dates = json.loads(f.read())
	with open(opendota_path, "r") as f:
		data = json.loads(f.read())
	for patch in data:
		if patch["name"] in patch_dates:
			actual_date = patch_dates[patch["name"]]
			patch["date"] = f"{actual_date}T00:00:00Z"

	with open(opendota_path, "w+") as f:
		f.write(json.dumps(data, indent=1))



# get_patch_dates()
# fix_opendota_patches()
# cache_patches()
get_current_versions()